summaryrefslogtreecommitdiffstats
path: root/kstyles/highcontrast/highcontrast.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 23:01:18 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-03 23:01:18 -0600
commitaa3abfa2a78cccfcb1f91d808753c79295d618e9 (patch)
treefe00218b08a670818d7ee67e677d1f6b5ded6eed /kstyles/highcontrast/highcontrast.h
parente92a4e05c504978308b2dd83082d2727b74bea8f (diff)
downloadtdelibs-aa3abfa2a78cccfcb1f91d808753c79295d618e9.tar.gz
tdelibs-aa3abfa2a78cccfcb1f91d808753c79295d618e9.zip
Rename KStyle to TDEStyle to avoid conflicts with KDE4
Diffstat (limited to 'kstyles/highcontrast/highcontrast.h')
-rw-r--r--kstyles/highcontrast/highcontrast.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kstyles/highcontrast/highcontrast.h b/kstyles/highcontrast/highcontrast.h
index 89a716dc1..1a721e8c6 100644
--- a/kstyles/highcontrast/highcontrast.h
+++ b/kstyles/highcontrast/highcontrast.h
@@ -14,7 +14,7 @@
* (C) 2000 Dirk Mueller <mueller@kde.org>
* (C) 2001 Martijn Klingens <klingens@kde.org>
*
* Includes portions from KStyle,
* Copyright (C) 2001-2002 Karol Szwed <gallium@kde.org>
*
* Many thanks to Bradley T. Hughes for the 3 button scrollbar code.
@@ -46,7 +46,7 @@
class TQPopupMenu;
-class HighContrastStyle : public KStyle
+class HighContrastStyle : public TDEStyle
{
Q_OBJECT
@@ -59,7 +59,7 @@ class HighContrastStyle : public KStyle
void polish( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void * );
void unPolish( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void * );
- void drawKStylePrimitive( KStylePrimitive kpe,
+ void drawTDEStylePrimitive( TDEStylePrimitive kpe,
TQPainter* p,
const TQStyleControlElementData &ceData,
ControlElementFlags elementFlags,
@@ -137,7 +137,7 @@ class HighContrastStyle : public KStyle
int pixelMetric( PixelMetric m, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
const TQWidget *widget = 0 ) const;
- int kPixelMetric( KStylePixelMetric m, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
+ int kPixelMetric( TDEStylePixelMetric m, const TQStyleControlElementData &ceData, ControlElementFlags elementFlags,
const TQWidget *widget = 0 ) const;
TQSize sizeFromContents( ContentsType contents,
@@ -14,7 +14,7 @@
* (C) 2001 Martijn Klingens <klingens@kde.org>
*
- * Includes portions from KStyle,
+ * Includes portions from TDEStyle,
* Copyright (C) 2001-2002 Karol Szwed <gallium@kde.org>
*